======
Config
======

Module: :mod:`jupyterlab_server.config`
=======================================

.. automodule:: jupyterlab_server.config

.. currentmodule:: jupyterlab_server.config

.. autofunction:: get_package_url

.. autofunction:: get_federated_extensions

.. autofunction:: get_static_page_config

.. autofunction:: get_page_config

.. autofunction:: write_page_config

:class:`LabConfig`
---------------------

.. autoconfigurable:: LabConfig
